// ADS Point lighting Shader
#version 330
uniform vec4 ambientColor;
uniform vec4 diffuseColor;   
uniform vec4 specularColor;
uniform float shininess; 
uniform sampler2D colorMap;
uniform sampler2DShadow shadowTexture;

in vec3 vVaryingNormal;
in vec3 vVaryingLightDir;
in vec2 vTexCoords;

in vec4 projCoord;

out vec4 vFragColor;

void main(void)
{ 
	// Dot product gives us diffuse intensity
	float diff = max(0.0, dot(normalize(vVaryingNormal), normalize(vVaryingLightDir)));

	// Multiply intensity by diffuse color, force alpha to 1.0
	vFragColor = diff * diffuseColor;

	// Add in ambient light
	vFragColor += ambientColor;

	// Specular Light
	vec3 vReflection = normalize(reflect(-normalize(vVaryingLightDir), normalize(vVaryingNormal)));
	float spec = max(0.0, dot(normalize(vVaryingNormal), vReflection));

	float shadow = textureProj(shadowTexture, projCoord);
	//float shadow;
	//shadow  = textureProjOffset(shadowTexture, projCoord, ivec2(-1,-1));
	//shadow += textureProjOffset(shadowTexture, projCoord, ivec2( 1,-1));
	//shadow += textureProjOffset(shadowTexture, projCoord, ivec2(-1, 1));
	//shadow += textureProjOffset(shadowTexture, projCoord, ivec2( 1, 1));

	shadow = shadow * 0.5 + 0.5;

	if(diff != 0)
	{
		float fSpec = pow(spec, shininess);
		if (shadow >= 0.5)
			vFragColor.rgb += vec3(fSpec, fSpec, fSpec);
	}

	vFragColor *= shadow;

	// Modulate in the texture
	vFragColor *= texture(colorMap, vTexCoords);

}
    